@@ -9,5 +9,5 @@ import staticjinja
 
 if __name__ == "__main__":
     searchpath = os.path.join(os.getcwd(), 'templates')
-    renderer = staticjinja.make_renderer(searchpath=searchpath)
-    renderer.run(use_reloader=True)
+    site = staticjinja.make_site(searchpath=searchpath)
+    site.render(use_reloader=True)
